@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,11 +9,11 @@
 #include "importmailjobinterface.h"
 #include "pimdataexportercore_private_export.h"
 #include <Akonadi/Collection>
-#include <Akonadi/KMime/SpecialMailCollections>
+#include <Akonadi/SpecialMailCollections>
 #include <KArchive>
+#include <MailTransport/TransportManager>
 #include <QHash>
 #include <QStringList>
-#include <MailTransport/TransportManager>
 class ArchiveStorage;
 namespace KIdentityManagement
 {
